@@ -2,7 +2,7 @@ import os.path
 import unittest
 import subprocess
 
-NAME = os.path.join('austaltools','command_line.py')
+CMD = ['python','-m','austaltools.command_line']
 SUBCMD = 'eap'
 def capture(command):
     proc = subprocess.Popen(command,
@@ -21,13 +21,13 @@ def verify_akterm(path):
 
 class TestCommandLine(unittest.TestCase):
     def test_no_param(self):
-        command = [NAME, SUBCMD]
+        command = CMD + [SUBCMD]
         out, err, exitcode = capture(command)
         self.assertEqual(exitcode, 1)
         self.assertRegex(err.decode(), 'grid 0 not available')
 
     def test_help(self):
-        command = [NAME, SUBCMD, '-h']
+        command = CMD + [SUBCMD, '-h']
         out, err, exitcode = capture(command)
         assert exitcode == 0
         assert out.decode().startswith('usage')
